@@ -43,6 +43,16 @@ class MutualFundScreener( object ):
         '''
         schemes = self.get_all_schemes()
         
+        if not isin_list:
+            isin_list = []
+            new_includes = []
+            for wrd in includes:
+                if wrd.lower().startswith("inf"):
+                    isin_list.append(wrd)
+                else:
+                    new_includes.append(wrd)
+            includes = new_includes
+            
         if isin_list:
             isin_list = [isin.lower() for isin in isin_list]
             schemes = schemes[(schemes['scheme_isin1'].str.lower().str.contains('|'.join(isin_list)) == True) |
@@ -53,6 +63,8 @@ class MutualFundScreener( object ):
         for wrd in excludes:
             schemes = schemes[(schemes['scheme_name'].str.lower().str.contains(wrd.lower()) == False)]
             
+        schemes = self.get_scheme_details( schemes.index.tolist())
+        
         return schemes
     
     def get_scheme_details( self, codes = ()):
