@@ -8,7 +8,7 @@ Description: Utility module for screener calculations
 import datetime
 import pandas as pd
 import logging as log
-import pandas_datareader as pdr
+from pandas_datareader import data as pdr
 import numpy as np
 import matplotlib.pyplot as plt
 import bs4 as bs
@@ -18,7 +18,9 @@ from collections.abc import Iterable
 from statsmodels.tsa.arima_model import ARIMA
 from sklearn.metrics import mean_squared_error
 from nsepy import get_history
+import yfinance as yfin
 
+yfin.pdr_override()
 #from .constant import STOCK_LIST
 
 def memoize( func ):
@@ -81,7 +83,7 @@ def getHistoricStockPricesFromYahoo( stock_name, start_date = None, end_date = N
         if end_date is None: end_date = datetime.datetime.today()
         if start_date is None: start_date = end_date + datetime.timedelta( days = -1* 365 )
 
-        hist_prices = pdr.DataReader(name = stock_name, data_source = 'yahoo',start = start_date, end = end_date)
+        hist_prices = pdr.get_data_yahoo(name = stock_name, start = start_date, end = end_date)
         return hist_prices
         
     except:
